﻿using System;
using System.Collections.Generic;
using GameOn.Web.Entities;
using GameOn.Web.Models;

namespace GameOn.Web.Services
{
    public interface IPlayerService
    {
        /// <summary>
        /// Gets a single player by ID
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Player GetPlayer(int id);

        /// <summary>
        /// Returns a ranked list of players, sorted by their ELO rating.
        /// </summary>
        /// <returns></returns>
        List<Player> GetPlayersByRank();

        /// <summary>
        /// Gets the top ranking player, mon
        /// </summary>
        Player GetTopRankingPlayer();

        /// <summary>
        /// Gets a summary of all of the matches that a Player has played
        /// </summary>
        PlayerMatchesSummary GetPlayerMatchesSummary(int playerId);

        /// <summary>
        /// Gets a list of players and summaries of all of the matches each Player has played
        /// </summary>
        List<PlayerMatchesSummary> GetListOfPlayersWithMatchSummaries();

        /// <summary>
        /// Gets a list of player IDs and comma-separated Rank data for drawing players' sparklines
        /// </summary>
        /// <returns>A list of tuples, each a player ID as int, and a list of Ranks as a comma-separated string</returns>
        List<Tuple<int, string>> GetRankHistoryDataForSparkLine();

        /// <summary>
        /// Gets a player ID and comma-separated Rank data for drawing a player's sparkline
        /// </summary>
        /// <param name="playerId">A player ID. Returns a </param>
        /// <returns>A tuple: a player ID as int, and a list of Ranks as a comma-separated string</returns>
        Tuple<int, string> GetRankHistoryDataForSparkLine(int playerId);

    }
}